@@ -920,7 +920,8 @@ class AddSubpartForm(forms.Form):
         super(AddSubpartForm, self).__init__(*args, **kwargs)
         self.fields['subpart_part_number'] = forms.CharField(required=True, label="Subpart part number",
                                                     widget=AutocompleteTextInput(attrs={'placeholder': 'Select a part.'},
-                                                                                 queryset=Part.objects.filter(organization=self.organization).exclude(id=self.part_id)))
+                                                                                 queryset=Part.objects.filter(organization=self.organization).exclude(id=self.part_id),
+                                                                                 verbose_string_function=Part.verbose_str))
 
     def clean_count(self):
         count = self.cleaned_data['count']
@@ -1210,7 +1211,7 @@ class BOMCSVForm(forms.Form):
 
                 if len(existing_subpart_qs) == 0:
 
-                    if len(reference_list) != count:
+                    if len(reference_list) != count and len(reference_list) > 0:
                         self.warnings.append(
                             f"The number of reference designators ({len(reference_list)}) for subpart {subpart_part} on row {row_count} does not match the subpart quantity ({count}). Quantity automatically adjusted.")
                         count = len(reference_list)
